<?php
/*
=====================================================
 Модуль Schema для киносайта - by UnderBeerDev
-----------------------------------------------------
 https://underbeerdev.pro/
-----------------------------------------------------
 Copyright (c) 2021 UnderBeerDev
=====================================================
 This code is protected by copyright
=====================================================
 File: schema.php
-----------------------------------------------------
 Use: Module code
=====================================================
*/

if( !defined('DATALIFEENGINE') ) {
	header( "HTTP/1.1 403 Forbidden" );
	header ( 'Location: ../../' );
	die( "Hacking attempt!" );
}

function clean_schema ($a) {
    global $config;
    return str_replace("&amp;amp;", "&amp;", htmlspecialchars( $a, ENT_QUOTES, $config['charset'] ) );
}

include_once ENGINE_DIR . '/underbeerdev/schema_org/config.php';
$xf_schema = xfieldsdataload( $row['xfields'] );

$schema_data = array();
$schema_data['@context'] = 'https://schema.org';
foreach ( $dle_schema['settings']['movie_cats'] as $movie_cat ) {
    if ( in_array($movie_cat, $cat_list ) ) $schema_data['@type'] = 'Movie';
}
foreach ( $dle_schema['settings']['tv_cats'] as $tv_cats ) {
    if ( in_array($tv_cats, $cat_list ) ) $schema_data['@type'] = 'TVSeries';
}
$schema_data['url'] = $full_link;
if ( $dle_schema['settings']['name'] ) {
    if ( $dle_schema['settings']['name'] == 'main_title' )
        $schema_data['name'] = clean_schema($row['title']);
    elseif ( $xf_schema[$dle_schema['settings']['name']] )
        $schema_data['name'] = clean_schema($xf_schema[$dle_schema['settings']['name']]);
}
if ( $dle_schema['settings']['alternativeHeadline'] && $xf_schema[$dle_schema['settings']['alternativeHeadline']] )
    $schema_data['alternativeHeadline'] = clean_schema($xf_schema[$dle_schema['settings']['alternativeHeadline']]);
if ( $dle_schema['settings']['alternateName'] && $xf_schema[$dle_schema['settings']['alternateName']] )
    $schema_data['alternateName'] = clean_schema($xf_schema[$dle_schema['settings']['alternativeHeadline']]);
if ( $dle_schema['settings']['description'] ) {
    if ( $dle_schema['settings']['description'] == 'main_short' )
        $schema_data['description'] = clean_schema($row['short_story']);
    elseif ( $dle_schema['settings']['description'] == 'main_full' )
        $schema_data['description'] = clean_schema($row['full_story']);
    elseif ( $xf_schema[$dle_schema['settings']['description']] )
        $schema_data['description'] = clean_schema($xf_schema[$dle_schema['settings']['description']]);
}
if ( $dle_schema['settings']['image'] && $xf_schema[$dle_schema['settings']['image']] )
    if ( stripos($xf_schema[$dle_schema['settings']['image']], 'posts') === false )
        $schema_data['image'] = $config['http_home_url'].'uploads/posts/'.$xf_schema[$dle_schema['settings']['image']];
    else
        $schema_data['image'] = $xf_schema[$dle_schema['settings']['image']];
if ( $dle_schema['settings']['genre'] && $xf_schema[$dle_schema['settings']['genre']] )
    $schema_data['genre'] = explode(', ', $xf_schema[$dle_schema['settings']['genre']]);
$schema_data['isFamilyFriendly'] = true;
if ( $dle_schema['settings']['numberOfEpisodes'] && $xf_schema[$dle_schema['settings']['numberOfEpisodes']] )
    $schema_data['numberOfEpisodes'] = intval(str_replace(' серия', '', $xf_schema[$dle_schema['settings']['numberOfEpisodes']]));
if ( $dle_schema['settings']['timeRequired'] && $xf_schema[$dle_schema['settings']['timeRequired']] )
    $schema_data['timeRequired'] = intval(str_replace(' мин.', '', $xf_schema[$dle_schema['settings']['timeRequired']]));
else
    $schema_data['timeRequired'] = 120;
if ( $dle_schema['settings']['datePublished'] && $xf_schema[$dle_schema['settings']['datePublished']] )
    $schema_data['datePublished'] = $xf_schema[$dle_schema['settings']['datePublished']];
if ( $xf_schema[$dle_schema['settings']['producer']] ) {
	foreach ( explode(', ', $xf_schema[$dle_schema['settings']['producer']]) as $pr_num => $pr_name ) {
		$schema_data['producer'][$pr_num]['@type'] = 'Person';
		$schema_data['producer'][$pr_num]['name'] = clean_schema($pr_name);
	}
}
if ( $xf_schema[$dle_schema['settings']['director']] ) {
	foreach ( explode(', ', $xf_schema[$dle_schema['settings']['director']]) as $dr_num => $dr_name ) {
		$schema_data['director'][$dr_num]['@type'] = 'Person';
		$schema_data['director'][$dr_num]['name'] = clean_schema($dr_name);
	}
}
if ( $xf_schema[$dle_schema['settings']['actor']] ) {
	foreach ( explode(', ', $xf_schema[$dle_schema['settings']['actor']]) as $ac_num => $ac_name ) {
		$schema_data['actor'][$ac_num]['@type'] = 'Person';
		$schema_data['actor'][$ac_num]['name'] = clean_schema($ac_name);
	}
}
if ( $xf_schema['country'] ) {
	foreach ( explode(', ', $xf_schema[$dle_schema['settings']['countryOfOrigin']]) as $co_num => $co_name ) {
		$schema_data['countryOfOrigin'][$co_num]['@type'] = 'Country';
		$schema_data['countryOfOrigin'][$co_num]['name'] = clean_schema($co_name);
	}
}
$schema_data['aggregateRating']['@type'] = 'AggregateRating';
$schema_data['aggregateRating']['bestRating'] = 10;
if ( $ratingscore > 0 ) {
	$schema_data['aggregateRating']['ratingValue'] = floatval($ratingscore);
	$schema_data['aggregateRating']['ratingCount'] = intval($row['vote_num']);
}
else {
	$schema_data['aggregateRating']['ratingValue'] = floatval('7.7');
	$schema_data['aggregateRating']['ratingCount'] = 1;
}
$schema_json = json_encode($schema_data, JSON_UNESCAPED_UNICODE|JSON_UNESCAPED_SLASHES);
$tpl->set( '{schema_org}', $schema_json );
create_cache( "schema", $schema_json, $row['id'], true );
unset($dle_schema, $xf_schema, $schema_data, $schema_json);